import { CSSProperties } from "react";
import { dataTheme } from "data-theme";
export interface Select extends React.InputHTMLAttributes<HTMLInputElement> {
    /**
     * Custom css class name.
     */
    inputClassName?: string;
    /**
     * Custom css class name for group wrapper.
     */
    classNameGroup?: string;
    /**
     * Data theme for the html. `${themes}`
     */
    paletteTheme?: dataTheme;
    /**
     * Options of the select component.
     */
    options?: string[];
    /**
     * Error message to show when input has an error.
     */
    error: {
        is: boolean;
        message: string;
    };
    /**
     * Style input group wrapper
     */
    styleGroup?: CSSProperties;
    /**Default selected value */
    defaultValue?: string;
    /**
     * Style of the backgroundColor
     */
    backgroundColor?: string;
    /**Pass a custom function to the select */
    handleSelect?: Function;
    /**Pass a custom function to the select */
    setFormSelected?: Function;
    /**Pass a custom function to the select on clear error*/
    clearError?: Function;
    /**Pass a custom function to the select on reset form*/
    resetForm?: Function;
    /**Pass a custom function to the select on form blur, when closing the select*/
    onFormBlur?: Function;
    /**Pass a custom label to the select*/
    label?: string;
    /**Pass a custom class to the label of the select*/
    labelClassName?: string;
    /**Sets if select is required or not*/
    isRequired: boolean;
}
