import { Dispatch, JSXElementConstructor, ReactElement, ReactNode, SetStateAction } from "react";
import { FieldError, FieldErrorsImpl, FieldValues, Merge, UseFormReturn } from "react-hook-form";
import { Input } from "../input/index.types";
import { TextArea } from "../text-area/index.types";
export interface Form {
    /**
     * Custom css class name.
     */
    className?: string;
    /**
     * In case the form has children to pass.
     */
    children?: ReactNode | ReactNode[];
    /**
     * Function that submits the form
     */
    onSubmit: (data: FieldValues, methods: UseFormReturn, setResult: SetResult) => void;
    /**
     * Text that goes on the submit form button.
     */
    submitButton?: {
        label: string;
    };
    /**
     * Initial state of the form, values that are defaults. Ex: name: "Test", type: "Test Type", subject: "Test Subject", [type]: "Test Type II",
     */
    initialState?: {
        defaultValues?: {
            name?: string;
            type?: string;
            subject?: string;
            customValues?: {
                [key: string]: string;
            };
        };
    };
    /**
     * Custom background color if needed.
     */
    backgroundColor?: string;
}
export interface ReactNodeControlled extends ReactElement<any, string | JSXElementConstructor<any>> {
    props: ControlledInput;
}
export type ControlledInput = Input & TextArea & {
    name: string;
    error: string;
};
export type SetResult = Dispatch<SetStateAction<{
    message?: string;
    isSuccess: boolean;
}>>;
export interface FormInputs extends Input {
    name: string;
    isRequired?: boolean;
    error?: {
        message?: string | false | FieldError | Merge<FieldError, FieldErrorsImpl<any>> | undefined;
        is?: boolean;
    };
}
export interface FormSelect {
    name: string;
    isRequired?: boolean;
    label: string;
    options: string[];
    error?: {
        message?: string | false | FieldError | Merge<FieldError, FieldErrorsImpl<any>> | undefined;
        is?: boolean;
    };
    fieldsToReset?: string[];
    handleSelect: Function;
}
